job "asapo-services" {
  datacenters = ["dc1"]

  type = "service"

  group "asapo-authorizer" {
    count = 1

    task "asapo-authorizer" {
      driver = "docker"

      config {
        network_mode = "host"
        dns_servers = ["127.0.0.1"]
        image = "yakser/asapo-authorizer${image_suffix}"
	force_pull = true
        volumes = ["local/config.json:/var/lib/authorizer/config.json"]
	%{ if fluentd_logs }
        logging {
            type = "fluentd"
            config {
                fluentd-address = "localhost:9881"
                fluentd-async-connect = true
                tag = "asapo.docker"
            }
        }
	%{endif}
      }

      resources {
        cpu    = 500 # 500 MHz
        memory = 256 # 256MB
        network {
          port "authorizer" {
            static = "5007"
          }
        }
      }

      service {
        name = "asapo-authorizer"
        port = "authorizer"
        check {
          name     = "alive"
          type     = "http"
          path     = "/health-check"
          interval = "10s"
          timeout  = "2s"
          initial_status =   "passing"
        }
        check_restart {
          limit = 2
          grace = "15s"
          ignore_warnings = false
        }
      }

      template {
         source        = "/usr/local/nomad_jobs/authorizer.json.tpl"
         destination   = "local/config.json"
         change_mode   = "restart"
      }
      template {
        source        = "/usr/local/nomad_jobs/auth_secret.key"
        destination   = "local/secret.key"
        change_mode   = "restart"
      }
   }
  } #authorizer
  group "asapo-discovery" {
    count = 1

    task "asapo-discovery" {
      driver = "docker"

      config {
        network_mode = "host"
        dns_servers = ["127.0.0.1"]
        image = "yakser/asapo-discovery${image_suffix}"
	    force_pull = true
        volumes = ["local/config.json:/var/lib/discovery/config.json"]
        logging {
            type = "fluentd"
            config {
                fluentd-address = "localhost:9881"
                fluentd-async-connect = true
                tag = "asapo.docker"
            }
        }
      }

      resources {
        cpu    = 500 # 500 MHz
        memory = 256 # 256MB
        network {
          port "discovery" {
            static = "5006"
          }
        }
      }

      service {
        name = "asapo-discovery"
        port = "discovery"
        check {
          name     = "alive"
          type     = "http"
          path     = "/receivers"
          interval = "10s"
          timeout  = "2s"
          initial_status =   "passing"
        }
        check_restart {
          limit = 2
          grace = "15s"
          ignore_warnings = false
        }

      }

      template {
         source        = "/usr/local/nomad_jobs/discovery.json.tpl"
         destination   = "local/config.json"
         change_mode   = "restart"
      }
   }
  }
}
